# JUNKYARD #
[![PyPI version shields.io](https://img.shields.io/pypi/v/junkyard.svg)](https://pypi.python.org/pypi/junkyard/)
[![PyPI status](https://img.shields.io/pypi/status/junkyard.svg)](https://pypi.python.org/pypi/junkyard/)
[![PyPI license](https://img.shields.io/pypi/l/junkyard.svg)](https://pypi.python.org/pypi/junkyard/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/junkyard.svg)](https://pypi.python.org/pypi/junkyard/)
<br>
<b>0.0.03a5 (HOTFIX)</b>

Download and docs: https://pypi.org/project/junkyard/
<br>
Source code & Development: https://github.com/crushkilldestroy/junkyard

Description
===========
A collection of various (probably certifiable-garbage) helper classes and modules designed by the author for use by the author, using PyCharm and
Anaconda (Python 3.7.X).
<br><br><br>

<i><b>Current features include</b></i>:

<b>CryptoHandler</b>(WIP/ON HOLD)<br>
 Does not currently do anything, but is intended to be a proper file and string encryption
 and decryption manager in the near future.

<b>DiagnosticsHandler</b>(WIP)<br>
 REMOVED UNTIL FURTHER NOTICE

<b>FileHandler</b>(WIP)<br>
 An attempt at leveraging standard library modules to accomplish routine filesystem tasks in a safe, reliable,
 and modular manner.

<b>PrintHandler</b>(WIP)<br>
 An attempt to create custom (colored/timestamped) print, and logging methods
<br><br>
Use <b>help(InsertClassNameHere)</b> in python to find out more information about available methods
or feel free to just poke through the code yourself!<br><br><br>

<i><b>If you would like to use my module, feel free to do so by using pip.</b></i><br>
<b>To install junkyard with pip</b>:
````python
pip install junkyard
````


License
=======

Copyright CKD 2019. MIT License; see LICENSE file.


Dependencies
============

<b>colorama</b> - to support the PrintHandler() class in garbagebasket.py<br>
[![PyPI version shields.io](https://img.shields.io/pypi/v/colorama.svg)](https://pypi.python.org/pypi/colorama/)
[![PyPI status](https://img.shields.io/pypi/status/colorama.svg)](https://pypi.python.org/pypi/colorama/)
[![PyPI license](https://img.shields.io/pypi/l/colorama.svg)](https://pypi.python.org/pypi/colorama/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/colorama.svg)](https://pypi.python.org/pypi/colorama/)
